@@ -1,8 +1,8 @@
 // This defines the API provided by this library.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -23,6 +23,7 @@
 
 
 #include <QJsonValue>
+#include <QMetaProperty>
 #include <QString>
 #include <QVariant>
 
@@ -54,11 +55,14 @@ QString qpycore_PyObject_AsQString(PyObject *obj);
 // Support for converting between PyObject and QVariant.
 PyObject *qpycore_PyObject_FromQVariant(const QVariant &qvar);
 QVariant qpycore_PyObject_AsQVariant(PyObject *obj, int *is_err);
+PyObject *qpycore_PyObject_FromQVariant(const QMetaProperty &mprop,
+        const QVariant &qvar);
+QVariant qpycore_PyObject_AsQVariant(const QMetaProperty &mprop, PyObject *obj,
+        bool *ok);
 
-// Support for Q_CLASSINFO(), Q_ENUMS() and Q_FLAGS().
-PyObject *qpycore_ClassInfo(const char *name, const char *value);
-PyObject *qpycore_Enums(PyObject *args);
-PyObject *qpycore_Flags(PyObject *args);
+// Support for pyqtClassInfo() and pyqtEnum().
+PyObject *qpycore_pyqtClassInfo(PyObject *args, PyObject *kwds);
+PyObject *qpycore_pyqtEnum(PyObject *enum_cls);
 
 // Support for creating QGenericArgument and QGenericReturnArgument instances.
 PyObject *qpycore_ArgumentFactory(PyObject *type, PyObject *data);
@@ -95,14 +99,19 @@ int qpycore_canConvertTo_QJsonValue(PyObject *py);
 int qpycore_convertTo_QJsonValue(PyObject *py, PyObject *transferObj,
         QJsonValue **cpp, int *isErr);
 
+// Support for an embedded qt.conf.
+bool qpycore_qt_conf();
+
 // Utilities.
-#if PY_MAJOR_VERSION >= 3
 void qpycore_Unicode_ConcatAndDel(PyObject **string, PyObject *newpart);
-#endif
 
 // Initialisation.
 void qpycore_init();
 void qpycore_post_init(PyObject *module_dict);
 
 
+// Termination.
+extern bool qpycore_created_qapp;
+
+
 #endif
