@@ -1,8 +1,8 @@
-// This defines the interfaces to the Q_CLASSINFO support.
+// This defines the interfaces to the pyqtClassInfo support.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -22,15 +22,10 @@
 #define _QPYCORE_CLASSINFO_H
 
 
-#include <QByteArray>
-#include <QList>
-#include <QPair>
-
-
 typedef QPair<QByteArray, QByteArray> ClassInfo;
 
 
-QList<ClassInfo> qpycore_get_class_info_list();
+QList<ClassInfo> qpycore_pop_class_info_list(PyObject *cls);
 
 
 #endif
