@@ -1,8 +1,8 @@
 // This contains the implementation of the PyQtSlotProxy class.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -22,8 +22,8 @@
 
 #include <QByteArray>
 #include <QMetaObject>
-#include <QMutex>
 #include <QObject>
+#include <QRecursiveMutex>
 
 #include "qpycore_api.h"
 #include "qpycore_chimera.h"
@@ -58,7 +58,7 @@ PyQtSlotProxy::PyQtSlotProxy(PyObject *slot, QObject *q_tx,
         signature(slot_signature->signature), transmitter(q_tx)
 {
     SIP_BLOCK_THREADS
-    real_slot = new PyQtSlot(slot, slot_signature);
+    real_slot = new PyQtSlot(slot, false, slot_signature);
     SIP_UNBLOCK_THREADS
 
     // Create a new meta-object on the heap so that it looks like it has a slot
@@ -133,7 +133,7 @@ PyQtSlotProxy::~PyQtSlotProxy()
 
 // The static members of PyQtSlotProxy.
 const QByteArray PyQtSlotProxy::proxy_slot_signature(SLOT(unislot()));
-QMutex *PyQtSlotProxy::mutex;
+QRecursiveMutex *PyQtSlotProxy::mutex;
 PyQtSlotProxy::ProxyHash PyQtSlotProxy::proxy_slots;
 
 
@@ -208,7 +208,7 @@ void PyQtSlotProxy::unislot(void **qargs)
         break;
 
     case PyQtSlot::Failed:
-        PyErr_Print();
+        pyqt6_err_print();
         break;
 
     case PyQtSlot::Ignored:
@@ -266,7 +266,7 @@ PyQtSlotProxy *PyQtSlotProxy::findSlotProxy(const QObject *transmitter,
     {
         PyQtSlotProxy *sp = it.value();
 
-        if (sp->signature == signal_signature && *(sp->real_slot) == slot)
+        if (!(sp->proxy_flags & PROXY_SLOT_DISABLED) && sp->signature == signal_signature && *(sp->real_slot) == slot)
         {
             proxy = sp;
             break;
@@ -281,6 +281,33 @@ PyQtSlotProxy *PyQtSlotProxy::findSlotProxy(const QObject *transmitter,
 }
 
 
+// Delete any slot proxy for a particular connection.
+void PyQtSlotProxy::deleteSlotProxy(const QMetaObject::Connection *connection)
+{
+    mutex->lock();
+
+    ProxyHash::iterator it(proxy_slots.begin());
+    ProxyHash::iterator end(proxy_slots.end());
+
+    while (it != end)
+    {
+        PyQtSlotProxy *sp = it.value();
+
+        if (sp->connection == *connection)
+        {
+            proxy_slots.erase(it);
+            sp->disable();
+
+            break;
+        }
+
+        ++it;
+    }
+
+    mutex->unlock();
+}
+
+
 // Delete any slot proxies for a particular transmitter and optional signal
 // signature.
 void PyQtSlotProxy::deleteSlotProxies(const QObject *transmitter,
