@@ -1,8 +1,8 @@
 // This is the support code for QMetaObject.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -32,11 +32,7 @@
 
 // Forward declarations.
 static PyObject *ArgumentStorage_New(PyObject *type, PyObject *data);
-#if defined(SIP_USE_PYCAPSULE)
 extern "C" {static void ArgumentStorage_delete(PyObject *cap);}
-#else
-extern "C" {static void ArgumentStorage_delete(void *stv);}
-#endif
 
 
 // Return a wrapped QGenericArgument for the given type and Python object.
@@ -50,13 +46,8 @@ PyObject *qpycore_ArgumentFactory(PyObject *type, PyObject *data)
         return 0;
     }
 
-#if defined(SIP_USE_PYCAPSULE)
     Chimera::Storage *st = reinterpret_cast<Chimera::Storage *>(
             PyCapsule_GetPointer(as_obj, NULL));
-#else
-    Chimera::Storage *st = reinterpret_cast<Chimera::Storage *>(
-            PyCObject_AsVoidPtr(as_obj));
-#endif
 
     QGenericArgument *arg = new QGenericArgument(
             st->type()->name().constData(), st->address());
@@ -67,7 +58,7 @@ PyObject *qpycore_ArgumentFactory(PyObject *type, PyObject *data)
     {
         // Stash the storage in the user field so that everything will be
         // properly garbage collected.
-        ((sipSimpleWrapper *)ga_obj)->user = as_obj;
+        sipSetUserObject((sipSimpleWrapper *)ga_obj, as_obj);
     }
     else
     {
@@ -90,13 +81,8 @@ PyObject *qpycore_ReturnFactory(PyObject *type)
         return 0;
     }
 
-#if defined(SIP_USE_PYCAPSULE)
     Chimera::Storage *st = reinterpret_cast<Chimera::Storage *>(
             PyCapsule_GetPointer(as_obj, NULL));
-#else
-    Chimera::Storage *st = reinterpret_cast<Chimera::Storage *>(
-            PyCObject_AsVoidPtr(as_obj));
-#endif
 
     QGenericReturnArgument *arg = new QGenericReturnArgument(
             st->type()->name().constData(), st->address());
@@ -108,7 +94,7 @@ PyObject *qpycore_ReturnFactory(PyObject *type)
     {
         // Stash the storage in the user field so that everything will be
         // properly garbage collected.
-        ((sipSimpleWrapper *)gra_obj)->user = as_obj;
+        sipSetUserObject((sipSimpleWrapper *)gra_obj, as_obj);
     }
     else
     {
@@ -123,21 +109,15 @@ PyObject *qpycore_ReturnFactory(PyObject *type)
 // Return the Python result from a QGenericReturnArgument.
 PyObject *qpycore_ReturnValue(PyObject *gra_obj)
 {
-    PyObject *as_obj = ((sipSimpleWrapper *)gra_obj)->user;
+    PyObject *as_obj = sipGetUserObject((sipSimpleWrapper *)gra_obj);
 
-#if defined(SIP_USE_PYCAPSULE)
     Chimera::Storage *st = reinterpret_cast<Chimera::Storage *>(
             PyCapsule_GetPointer(as_obj, NULL));
-#else
-    Chimera::Storage *st = reinterpret_cast<Chimera::Storage *>(
-            PyCObject_AsVoidPtr(as_obj));
-#endif
 
     return st->toPyObject();
 }
 
 
-#if defined(SIP_USE_PYCAPSULE)
 // The PyCapsule destructor for the ArgumentStorage type.
 static void ArgumentStorage_delete(PyObject *cap)
 {
@@ -148,17 +128,6 @@ static void ArgumentStorage_delete(PyObject *cap)
     delete st;
     delete ct;
 }
-#else
-// The PyCObject destructor for the ArgumentStorage type.
-static void ArgumentStorage_delete(void *stv)
-{
-    Chimera::Storage *st = reinterpret_cast<Chimera::Storage *>(stv);
-    const Chimera *ct = st->type();
-
-    delete st;
-    delete ct;
-}
-#endif
 
 
 // Returns a Python object wrapping an ArgumentStorage instance.
@@ -183,11 +152,7 @@ static PyObject *ArgumentStorage_New(PyObject *type, PyObject *data)
     }
 
     // Convert to a Python object.
-#if defined(SIP_USE_PYCAPSULE)
     PyObject *as_obj = PyCapsule_New(st, NULL, ArgumentStorage_delete);
-#else
-    PyObject *as_obj = PyCObject_FromVoidPtr(st, ArgumentStorage_delete);
-#endif
 
     if (!as_obj)
     {
