@@ -1,12 +1,9 @@
-// This defines the subset of the interface to Qt5's internal
-// QMetaObjectBuilder class.  The internal representation of a QMetaObject
-// changed in Qt5 (specifically revision 7) sufficiently to justify using this
-// internal code.  The alternative would be to reverse engineer other internal
-// data structures which would be even more fragile.
+// This defines the subset of the interface to Qt6's internal
+// QMetaObjectBuilder class.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -29,6 +26,7 @@
 #include <QByteArray>
 #include <QList>
 #include <QMetaObject>
+#include <QMetaType>
 
 QT_BEGIN_NAMESPACE
 
@@ -94,6 +92,8 @@ public:
     void setEnumOrFlag(bool value);
     void setConstant(bool value);
     void setFinal(bool value);
+    void setAlias(bool value);
+    void setBindable(bool value);
     void setRevision(int revision);
 
 private:
@@ -107,7 +107,9 @@ class Q_CORE_EXPORT QMetaEnumBuilder
 public:
     QMetaEnumBuilder() : _mobj(0), _index(0) {}
 
+    void setMetaType(QMetaType value);
     void setIsFlag(bool value);
+    void setIsScoped(bool value);
     int addKey(const QByteArray &name, int value);
 
 private:
