@@ -1,8 +1,8 @@
 // This implements the helpers for QObject.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -29,6 +29,8 @@
 
 #include "qpycore_api.h"
 #include "qpycore_chimera.h"
+#include "qpycore_misc.h"
+#include "qpycore_objectified_strings.h"
 #include "qpycore_pyqtboundsignal.h"
 #include "qpycore_pyqtproperty.h"
 #include "qpycore_pyqtpyobject.h"
@@ -48,12 +50,9 @@ static int qt_metacall_worker(sipSimpleWrapper *pySelf, PyTypeObject *pytype,
 const QMetaObject *qpycore_qobject_metaobject(sipSimpleWrapper *pySelf,
         sipTypeDef *base)
 {
-    // Return the dynamic meta-object if there is one.
-    if (pySelf && ((pyqtWrapperType *)Py_TYPE(pySelf))->metaobject)
-        return ((pyqtWrapperType *)Py_TYPE(pySelf))->metaobject->mo;
+    sipWrapperType *wt = (pySelf ? (sipWrapperType *)Py_TYPE(pySelf) : 0);
 
-    // Fall back to the static Qt meta-object.
-    return reinterpret_cast<const QMetaObject *>(((pyqt5ClassTypeDef *)base)->static_metaobject);
+    return qpycore_get_qmetaobject(wt, base);
 }
 
 
@@ -65,11 +64,7 @@ int qpycore_qobject_qt_metacall(sipSimpleWrapper *pySelf, sipTypeDef *base,
     if (!pySelf)
         return -1;
 
-    SIP_BLOCK_THREADS
-    _id = qt_metacall_worker(pySelf, Py_TYPE(pySelf), base, _c, _id, _a);
-    SIP_UNBLOCK_THREADS
-
-    return _id;
+    return qt_metacall_worker(pySelf, Py_TYPE(pySelf), base, _c, _id, _a);
 }
 
 
@@ -81,13 +76,16 @@ static int qt_metacall_worker(sipSimpleWrapper *pySelf, PyTypeObject *pytype,
     if (pytype == sipTypeAsPyTypeObject(base))
         return _id;
 
-    _id = qt_metacall_worker(pySelf, pytype->tp_base, base, _c, _id, _a);
+    PyTypeObject *tp_base = reinterpret_cast<PyTypeObject *>(
+            PyType_GetSlot(pytype, Py_tp_base));
+
+    _id = qt_metacall_worker(pySelf, tp_base, base, _c, _id, _a);
 
     if (_id < 0)
         return _id;
 
-    pyqtWrapperType *pyqt_wt = (pyqtWrapperType *)pytype;
-    qpycore_metaobject *qo = pyqt_wt->metaobject;
+    const qpycore_metaobject *qo = qpycore_get_dynamic_metaobject(
+            (sipWrapperType *)pytype);
 
     bool ok = true;
 
@@ -189,21 +187,11 @@ static int qt_metacall_worker(sipSimpleWrapper *pySelf, PyTypeObject *pytype,
 
         _id -= qo->pprops.count();
     }
-    else if (_c == QMetaObject::QueryPropertyDesignable)
-        _id -= qo->pprops.count();
-    else if (_c == QMetaObject::QueryPropertyScriptable)
-        _id -= qo->pprops.count();
-    else if (_c == QMetaObject::QueryPropertyStored)
-        _id -= qo->pprops.count();
-    else if (_c == QMetaObject::QueryPropertyEditable)
-        _id -= qo->pprops.count();
-    else if (_c == QMetaObject::QueryPropertyUser)
-        _id -= qo->pprops.count();
 
     // Handle any Python errors.
     if (!ok)
     {
-        PyErr_Print();
+        pyqt6_err_print();
         return -1;
     }
 
@@ -218,48 +206,62 @@ bool qpycore_qobject_qt_metacast(sipSimpleWrapper *pySelf,
     *sipCpp = 0;
 
     if (!_clname)
-        return true;
+        return false;
 
     // Check if the Python object has gone.
     if (!pySelf)
-        return true;
+        return false;
 
     bool is_py_class = false;
 
     SIP_BLOCK_THREADS
 
     PyTypeObject *base_pytype = sipTypeAsPyTypeObject(base);
-    PyObject *mro = Py_TYPE(pySelf)->tp_mro;
 
-    for (SIP_SSIZE_T i = 0; i < PyTuple_GET_SIZE(mro); ++i)
+    // We only need to look at the MRO if the object is a wrapped type (rather
+    // than a user sub-class).
+    if (base_pytype != Py_TYPE(pySelf))
     {
-        PyTypeObject *pytype = (PyTypeObject *)PyTuple_GET_ITEM(mro, i);
+        PyObject *mro = PyObject_GetAttr((PyObject *)Py_TYPE(pySelf),
+                qpycore_dunder_mro);
+        Q_ASSERT(mro);
 
-        if (!PyObject_IsInstance((PyObject *)pytype, (PyObject *)&qpycore_pyqtWrapperType_Type))
-            continue;
-
-        const sipTypeDef *td = ((sipWrapperType *)pytype)->type;
-
-        if (qstrcmp(pytype->tp_name, _clname) == 0)
+        for (Py_ssize_t i = 0; i < PyTuple_Size(mro); ++i)
         {
-            // The generated type definitions represent the C++ (rather than
-            // Python) hierachy.  If the C++ hierachy doesn't match then the
-            // super-type must be provided by a mixin.
-            if (PyType_IsSubtype(base_pytype, pytype))
-                *sipCpp = sipGetAddress(pySelf);
-            else
+            PyTypeObject *pytype = (PyTypeObject *)PyTuple_GetItem(mro, i);
+
+            const sipTypeDef *td = sipTypeFromPyTypeObject(pytype);
+
+            if (!td || !qpycore_is_pyqt_type(td))
+                continue;
+
+            if (qstrcmp(sipPyTypeName(pytype), _clname) == 0)
+            {
+                // The generated type definitions represent the C++ (rather
+                // than Python) hierachy.  If the C++ hierachy doesn't match
+                // then the super-type must be provided by a mixin.  Note that
+                // we check the type in both "directions" as we may be either
+                // "side" of the base type in the MRO.
+                if (PyType_IsSubtype(pytype, base_pytype) || PyType_IsSubtype(base_pytype, pytype))
+                    *sipCpp = sipGetAddress(pySelf);
+                else
+                    *sipCpp = sipGetMixinAddress(pySelf, td);
+
+                is_py_class = true;
+                break;
+            }
+
+            const pyqt6ClassPluginDef *plugin = reinterpret_cast<const pyqt6ClassPluginDef *>(sipTypePluginData(td));
+
+            if (plugin && plugin->qt_interface && qstrcmp(plugin->qt_interface, _clname) == 0)
+            {
                 *sipCpp = sipGetMixinAddress(pySelf, td);
-
-            is_py_class = true;
-            break;
+                is_py_class = true;
+                break;
+            }
         }
 
-        if (((pyqt5ClassTypeDef *)td)->qt_interface && qstrcmp(((pyqt5ClassTypeDef *)td)->qt_interface, _clname) == 0)
-        {
-            *sipCpp = sipGetMixinAddress(pySelf, td);
-            is_py_class = true;
-            break;
-        }
+        Py_DECREF(mro);
     }
 
     SIP_UNBLOCK_THREADS
@@ -271,33 +273,19 @@ bool qpycore_qobject_qt_metacast(sipSimpleWrapper *pySelf,
 // This is a helper for QObject.staticMetaObject %GetCode.
 PyObject *qpycore_qobject_staticmetaobject(PyObject *type_obj)
 {
-    pyqtWrapperType *pyqt_wt = (pyqtWrapperType *)type_obj;
-    const QMetaObject *mo;
+    const QMetaObject *mo = qpycore_get_qmetaobject((sipWrapperType *)type_obj);
 
-    if (pyqt_wt->metaobject)
+    if (!mo)
     {
-        // It's a sub-type of a wrapped type.
-        mo = pyqt_wt->metaobject->mo;
-    }
-    else
-    {
-        // It's a wrapped type.
-        pyqt5ClassTypeDef *pyqt_ctd = (pyqt5ClassTypeDef *)((sipWrapperType *)pyqt_wt)->type;
+        // We assume that this is a side effect of a wrapped class not being
+        // fully ready until sip's meta-class's __init__() has run (rather than
+        // after its __new__() method as might be expected).
+        PyErr_SetString(PyExc_AttributeError,
+                "staticMetaObject isn't available until the meta-class's __init__ returns");
 
-        if (!pyqt_ctd)
-        {
-            /*
-             * This is a side effect of a wrapped class not being fully ready
-             * until sip's meta-class's __init__() has run (rather than after
-             * its __new__() method as might be expected).
-             */
-            PyErr_SetString(PyExc_AttributeError,
-                    "staticMetaObject isn't available until the meta-class's __init__ returns");
-            return 0;
-        }
-
-        mo = reinterpret_cast<const QMetaObject *>(pyqt_ctd->static_metaobject);
+        return 0;
     }
 
-    return sipConvertFromType(const_cast<QMetaObject *>(mo), sipType_QMetaObject, 0);
+    return sipConvertFromType(const_cast<QMetaObject *>(mo),
+            sipType_QMetaObject, 0);
 }
