@@ -1,8 +1,8 @@
 // This contains the meta-type used by PyQt.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -27,32 +27,10 @@
 #include <QMetaType>
 #include <QPair>
 
-// Defining PYQT_QOBJECT_GUARD will enable code that tries to detect when a
-// QObject created by Qt (ie. where we don't have a generated virtual dtor) is
-// destroyed thus allowing us to raise an exception rather than crashing.
-// However, there are problems:
-//
-// 1. The obvious choice to implement this is QWeakPointer.  However it cannot
-//    be used across threads.  The code checks to see if QObject is in the
-//    current thread, but can't do anything about the QObject being moved to
-//    another thread later on.
-//
-// 2. A QObject dtor may invoke a Python reimplementation that causes the
-//    QObject to be wrapped.  QWeakPointer will fail an assertion if it is
-//    being created for a QObject that is being deleted (rather than the more
-//    sensible behaviour of creating a null QWeakPointer).
-//
-// For the moment we disable the code until we have a better solution.  (If you
-// connect the destroyed signal of a QObject then move the QObject to a
-// different thread, will the signal be delivered properly?)
-#if defined(PYQT_QOBJECT_GUARD)
-#include <QThread>
-#include <QWeakPointer>
-#endif
-
 #include "qpycore_chimera.h"
 #include "qpycore_classinfo.h"
 #include "qpycore_enums_flags.h"
+#include "qpycore_enums_flags_metatype.h"
 #include "qpycore_misc.h"
 #include "qpycore_objectified_strings.h"
 #include "qpycore_pyqtproperty.h"
@@ -69,136 +47,59 @@ typedef QPair<PyObject *, PyObject *> PropertyData;
 
 
 // Forward declarations.
-extern "C" {
-static int pyqtWrapperType_init(pyqtWrapperType *self, PyObject *args,
-        PyObject *kwds);
-#if defined(PYQT_QOBJECT_GUARD)
-static PyObject *pyqtWrapperType_call(PyObject *type, PyObject *args,
-        PyObject *kwds);
-static void *qpointer_access_func(sipSimpleWrapper *w, AccessFuncOp op);
-#endif
-}
-
 static int trawl_hierarchy(PyTypeObject *pytype, qpycore_metaobject *qo,
-        QMetaObjectBuilder &builder, QList<const qpycore_pyqtSignal *> &psigs,
+        QMetaObjectBuilder &builder, QList<EnumFlag> &penums,
+        QList<const qpycore_pyqtSignal *> &psigs,
         QMap<uint, PropertyData> &pprops);
 static int trawl_type(PyTypeObject *pytype, qpycore_metaobject *qo,
-        QMetaObjectBuilder &builder, QList<const qpycore_pyqtSignal *> &psigs,
+        QMetaObjectBuilder &builder, QList<EnumFlag> &penums,
+        QList<const qpycore_pyqtSignal *> &psigs,
         QMap<uint, PropertyData> &pprops);
-static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt);
 static const QMetaObject *get_scope_qmetaobject(const Chimera *ct);
-static const QMetaObject *get_qmetaobject(pyqtWrapperType *pyqt_wt);
-
-
-// The meta-type for PyQt classes.
-PyTypeObject qpycore_pyqtWrapperType_Type = {
-    PyVarObject_HEAD_INIT(NULL, 0)
-    SIP_TPNAME_CAST("PyQt5.QtCore.pyqtWrapperType"),    /* tp_name */
-    sizeof (pyqtWrapperType),   /* tp_basicsize */
-    0,                      /* tp_itemsize */
-    0,                      /* tp_dealloc */
-    0,                      /* tp_print */
-    0,                      /* tp_getattr */
-    0,                      /* tp_setattr */
-    0,                      /* tp_compare */
-    0,                      /* tp_repr */
-    0,                      /* tp_as_number */
-    0,                      /* tp_as_sequence */
-    0,                      /* tp_as_mapping */
-    0,                      /* tp_hash */
-#if defined(PYQT_QOBJECT_GUARD)
-    pyqtWrapperType_call,   /* tp_call */
-#else
-    0,                      /* tp_call */
-#endif
-    0,                      /* tp_str */
-    0,                      /* tp_getattro */
-    0,                      /* tp_setattro */
-    0,                      /* tp_as_buffer */
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,   /* tp_flags */
-    0,                      /* tp_doc */
-    0,                      /* tp_traverse */
-    0,                      /* tp_clear */
-    0,                      /* tp_richcompare */
-    0,                      /* tp_weaklistoffset */
-    0,                      /* tp_iter */
-    0,                      /* tp_iternext */
-    0,                      /* tp_methods */
-    0,                      /* tp_members */
-    0,                      /* tp_getset */
-    0,                      /* tp_base */
-    0,                      /* tp_dict */
-    0,                      /* tp_descr_get */
-    0,                      /* tp_descr_set */
-    0,                      /* tp_dictoffset */
-    (initproc)pyqtWrapperType_init, /* tp_init */
-    0,                      /* tp_alloc */
-    0,                      /* tp_new */
-    0,                      /* tp_free */
-    0,                      /* tp_is_gc */
-    0,                      /* tp_bases */
-    0,                      /* tp_mro */
-    0,                      /* tp_cache */
-    0,                      /* tp_subclasses */
-    0,                      /* tp_weaklist */
-    0,                      /* tp_del */
-    0,                      /* tp_version_tag */
-#if PY_VERSION_HEX >= 0x03040000
-    0,                      /* tp_finalize */
-#endif
-};
-
-
-// The type init slot.
-static int pyqtWrapperType_init(pyqtWrapperType *self, PyObject *args,
-        PyObject *kwds)
-{
-    // Let the super-type complete the basic initialisation.
-    if (sipWrapperType_Type->tp_init((PyObject *)self, args, kwds) < 0)
-        return -1;
-
-    pyqt5ClassTypeDef *pyqt_td = (pyqt5ClassTypeDef *)((sipWrapperType *)self)->type;
-
-    if (pyqt_td && !sipIsExactWrappedType((sipWrapperType *)self))
-    {
-        // Create a dynamic meta-object as its base wrapped type has a static
-        // Qt meta-object.
-        if (pyqt_td->static_metaobject && create_dynamic_metaobject(self) < 0)
-            return -1;
-    }
-
-    return 0;
-}
 
 
 // Create a dynamic meta-object for a Python type by introspecting its
 // attributes.  Note that it leaks if the type is deleted.
-static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
+const qpycore_metaobject *qpycore_get_dynamic_metaobject(sipWrapperType *wt)
 {
-    PyTypeObject *pytype = (PyTypeObject *)pyqt_wt;
-    qpycore_metaobject *qo = new qpycore_metaobject;
+    qpycore_metaobject *qo = reinterpret_cast<qpycore_metaobject *>(
+            sipGetTypeUserData(wt));
+
+    // Return any QMetaObject from a previous call.
+    if (qo)
+        return qo;
+
+    PyTypeObject *pytype = (PyTypeObject *)wt;
+
+    const pyqt6ClassPluginDef *plugin = reinterpret_cast<const pyqt6ClassPluginDef *>(sipTypePluginData(sipTypeFromPyTypeObject(pytype)));
+
+    // Only create a dynamic meta-object if its base wrapped type has a static
+    // Qt meta-object.
+    if (!plugin || !plugin->static_metaobject)
+        return 0;
+
     QMetaObjectBuilder builder;
 
-    // Get any class info.
-    QList<ClassInfo> class_info_list = qpycore_get_class_info_list();
-
-    // Get any enums/flags.
-    QList<EnumsFlags> enums_flags_list = qpycore_get_enums_flags_list();
-
     // Get the super-type's meta-object.
-    builder.setSuperClass(get_qmetaobject((pyqtWrapperType *)pytype->tp_base));
+    PyTypeObject *tp_base = reinterpret_cast<PyTypeObject *>(
+            PyType_GetSlot(pytype, Py_tp_base));
+
+    builder.setSuperClass(qpycore_get_qmetaobject((sipWrapperType *)tp_base));
 
     // Get the name of the type.  Dynamic types have simple names.
-    builder.setClassName(pytype->tp_name);
+    builder.setClassName(sipPyTypeName(pytype));
 
-    // Go through the class hierarchy getting all PyQt properties, slots and
-    // signals.
+    // Go through the class hierarchy getting all PyQt enums, properties, slots
+    // and signals.
 
+    QList<EnumFlag> penums;
     QList<const qpycore_pyqtSignal *> psigs;
     QMap<uint, PropertyData> pprops;
 
-    if (trawl_hierarchy(pytype, qo, builder, psigs, pprops) < 0)
-        return -1;
+    qo = new qpycore_metaobject;
+
+    if (trawl_hierarchy(pytype, qo, builder, penums, psigs, pprops) < 0)
+        return 0;
 
     qo->nr_signals = psigs.count();
 
@@ -210,7 +111,10 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
     // decorate __init__).
 
     // Set up any class information.
-    for (int i = 0; i < class_info_list.count(); ++i)
+    QList<ClassInfo> class_info_list = qpycore_pop_class_info_list(
+            (PyObject *)pytype);
+
+    for (int i = 0; i < class_info_list.length(); ++i)
     {
         const ClassInfo &ci = class_info_list.at(i);
 
@@ -218,22 +122,20 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
     }
 
     // Set up any enums/flags.
-    for (int i = 0; i < enums_flags_list.count(); ++i)
+    for (int i = 0; i < penums.count(); ++i)
     {
-        const EnumsFlags &ef = enums_flags_list.at(i);
-
-        QByteArray scoped_name(pytype->tp_name);
-        scoped_name.append("::");
-        scoped_name.append(ef.name);
-        QMetaEnumBuilder enum_builder = builder.addEnumerator(scoped_name);
+        const EnumFlag &ef = penums.at(i);
 
+        QMetaEnumBuilder enum_builder = builder.addEnumerator(ef.name);
+        enum_builder.setMetaType(ef.metaType);
         enum_builder.setIsFlag(ef.isFlag);
+        enum_builder.setIsScoped(true);
 
-        QHash<QByteArray, int>::const_iterator it = ef.keys.constBegin();
+        QList<QPair<QByteArray, int> >::const_iterator it = ef.keys.constBegin();
 
         while (it != ef.keys.constEnd())
         {
-            enum_builder.addKey(it.key(), it.value());
+            enum_builder.addKey(it->first, it->second);
             ++it;
         }
     }
@@ -270,12 +172,12 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
     // Add the properties to the meta-object.
     QMapIterator<uint, PropertyData> it(pprops);
 
-    for (int p = 0; it.hasNext(); ++p)
+    while (it.hasNext())
     {
         it.next();
 
         const PropertyData &pprop = it.value();
-        const char *prop_name = SIPBytes_AS_STRING(pprop.first);
+        const char *prop_name = PyBytes_AsString(pprop.first);
         qpycore_pyqtProperty *pp = (qpycore_pyqtProperty *)pprop.second;
         int notifier_id;
 
@@ -293,7 +195,7 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
                         sig.constData() + 1);
 
                 // Note that we leak the property name.
-                return -1;
+                return 0;
             }
         }
         else
@@ -313,14 +215,15 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
         // return "QObject*".
         QByteArray prop_type;
 
-        if (pp->pyqtprop_parsed_type->metatype() == QMetaType::QObjectStar)
+        if (pp->pyqtprop_parsed_type->metatype.id() == QMetaType::QObjectStar)
         {
             // However, if the type is a Python sub-class of QObject then we
             // use the name of the Python type.  This anticipates that the type
             // is one that will be proxied by QML at some point.
             if (pp->pyqtprop_parsed_type->typeDef() == sipType_QObject)
             {
-                prop_type = ((PyTypeObject *)pp->pyqtprop_parsed_type->py_type())->tp_name;
+                prop_type = sipPyTypeName(
+                        (PyTypeObject *)pp->pyqtprop_parsed_type->py_type());
                 prop_type.append('*');
             }
             else
@@ -333,15 +236,21 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
             prop_type = pp->pyqtprop_parsed_type->name();
         }
 
-        QMetaPropertyBuilder prop_builder = builder.addProperty(prop_name,
-                prop_type, notifier_id);
+        // Note that there is an addProperty() overload that also takes a
+        // QMetaType argument (rather than call QMetaType::fromName() as this
+        // overload does) so we could pass the QMetaType that the parser
+        // created.  However this breaks properties that are application Python
+        // enums which have a parsed QMetaType that describes an int whereas Qt
+        // seems to need an invalid QMetaType for these to work.
+        QMetaPropertyBuilder prop_builder = builder.addProperty(
+                QByteArray(prop_name), prop_type, notifier_id);
 
         // Reset the defaults.
         prop_builder.setReadable(false);
         prop_builder.setWritable(false);
 
         // Enum or flag.
-        if (pp->pyqtprop_parsed_type->isEnum() || pp->pyqtprop_parsed_type->isFlag())
+        if (pp->pyqtprop_parsed_type->isEnumOrFlag())
         {
             prop_builder.setEnumOrFlag(true);
         }
@@ -364,20 +273,11 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
 
             if (setter_name_obj)
             {
-                PyObject *ascii_obj = setter_name_obj;
-                const char *ascii = sipString_AsASCIIString(&ascii_obj);
+                QByteArray ascii = qpycore_convert_ASCII(setter_name_obj);
                 Py_DECREF(setter_name_obj);
 
-                if (ascii)
-                {
-                    if (qstrlen(ascii) > 3 && ascii[0] == 's' &&
-                            ascii[1] == 'e' && ascii[2] == 't' &&
-                            ascii[3] == toupper(prop_name[0]) &&
-                            qstrcmp(&ascii[4], &prop_name[1]) == 0)
-                        prop_builder.setStdCppSet(true);
-                }
-
-                Py_DECREF(ascii_obj);
+                if (ascii.startsWith("set") && ascii[3] == (char)toupper(prop_name[0]) && ascii.mid(4) == prop_name + 1)
+                    prop_builder.setStdCppSet(true);
             }
 
             PyErr_Clear();
@@ -385,13 +285,11 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
 
         if (pp->pyqtprop_reset && PyCallable_Check(pp->pyqtprop_reset))
         {
-            // Resetable.
+            // Resettable.
             prop_builder.setResettable(true);
         }
 
-        // Add the property flags.  Note that Qt4 always seems to have
-        // ResolveEditable set but QMetaObjectBuilder doesn't provide an API
-        // call to do it.
+        // Add the property flags.
         prop_builder.setDesignable(pp->pyqtprop_flags & 0x00001000);
         prop_builder.setScriptable(pp->pyqtprop_flags & 0x00004000);
         prop_builder.setStored(pp->pyqtprop_flags & 0x00010000);
@@ -409,37 +307,57 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
         Py_DECREF(pprop.first);
     }
 
-    // Initialise the rest of the meta-object.
+    // Build the meta-object.
     qo->mo = builder.toMetaObject();
 
-    // Save the meta-object.
-    pyqt_wt->metaobject = qo;
+    // Save the meta-object in any enums/flags.
+    for (int i = 0; i < penums.count(); ++i)
+    {
+        const EnumFlag &ef = penums.at(i);
 
-    return 0;
+        static_cast<EnumFlagMetaTypeInterface *>(
+                const_cast<QtPrivate::QMetaTypeInterface *>(
+                        ef.metaType.iface()))->metaObject = qo->mo;
+    }
+
+    // Save for next time.
+    sipSetTypeUserData(wt, qo);
+
+    return qo;
 }
 
 
-// Trawl a type's hierarchy looking for any slots, signals or properties.
+// Trawl a type's hierarchy looking for any enums, slots, signals or
+// properties.
 static int trawl_hierarchy(PyTypeObject *pytype, qpycore_metaobject *qo,
-        QMetaObjectBuilder &builder, QList<const qpycore_pyqtSignal *> &psigs,
+        QMetaObjectBuilder &builder, QList<EnumFlag> &penums,
+        QList<const qpycore_pyqtSignal *> &psigs,
         QMap<uint, PropertyData> &pprops)
 {
-    if (trawl_type(pytype, qo, builder, psigs, pprops) < 0)
+    if (trawl_type(pytype, qo, builder, penums, psigs, pprops) < 0)
         return -1;
 
-    if (!pytype->tp_bases)
+    PyObject *tp_bases;
+
+    if (PyType_HasFeature(pytype, Py_TPFLAGS_HEAPTYPE))
+        tp_bases = reinterpret_cast<PyObject *>(
+                PyType_GetSlot(pytype, Py_tp_bases));
+    else
+        tp_bases = 0;
+
+    if (!tp_bases)
         return 0;
 
-    Q_ASSERT(PyTuple_Check(pytype->tp_bases));
+    Q_ASSERT(PyTuple_Check(tp_bases));
 
-    for (SIP_SSIZE_T i = 0; i < PyTuple_GET_SIZE(pytype->tp_bases); ++i)
+    for (Py_ssize_t i = 0; i < PyTuple_Size(tp_bases); ++i)
     {
-        PyTypeObject *sup = (PyTypeObject *)PyTuple_GET_ITEM(pytype->tp_bases, i);
+        PyTypeObject *sup = (PyTypeObject *)PyTuple_GetItem(tp_bases, i);
 
         if (PyType_IsSubtype(sup, sipTypeAsPyTypeObject(sipType_QObject)))
             continue;
 
-        if (trawl_hierarchy(sup, qo, builder, psigs, pprops) < 0)
+        if (trawl_hierarchy(sup, qo, builder, penums, psigs, pprops) < 0)
             return -1;
     }
 
@@ -447,16 +365,29 @@ static int trawl_hierarchy(PyTypeObject *pytype, qpycore_metaobject *qo,
 }
 
 
-// Trawl a type's dict looking for any slots, signals or properties.
+// Trawl a type's dict looking for any enums, slots, signals or properties.
 static int trawl_type(PyTypeObject *pytype, qpycore_metaobject *qo,
-        QMetaObjectBuilder &builder, QList<const qpycore_pyqtSignal *> &psigs,
+        QMetaObjectBuilder &builder, QList<EnumFlag> &penums,
+        QList<const qpycore_pyqtSignal *> &psigs,
         QMap<uint, PropertyData> &pprops)
 {
-    SIP_SSIZE_T pos = 0;
-    PyObject *key, *value;
+    int rc = 0;
+    Py_ssize_t pos = 0;
+    PyObject *key, *value, *dict;
 
-    while (PyDict_Next(pytype->tp_dict, &pos, &key, &value))
+    if ((dict = sipPyTypeDictRef(pytype)) == NULL)
+        return -1;
+
+    while (PyDict_Next(dict, &pos, &key, &value))
     {
+        // See if it is an enum.
+        EnumFlag enum_flag = qpycore_pop_enum_flag(value);
+        if (!enum_flag.name.isNull())
+        {
+            penums.append(enum_flag);
+            continue;
+        }
+
         // See if it is a slot, ie. it has been decorated with pyqtSlot().
         PyObject *sig_obj = PyObject_GetAttr(value,
                 qpycore_dunder_pyqtsignature);
@@ -467,16 +398,27 @@ static int trawl_type(PyTypeObject *pytype, qpycore_metaobject *qo,
             // happens to use our special name.
             if (PyList_Check(sig_obj))
             {
-                for (SIP_SSIZE_T i = 0; i < PyList_GET_SIZE(sig_obj); ++i)
+                for (Py_ssize_t i = 0; i < PyList_Size(sig_obj); ++i)
                 {
                     // Set up the skeleton slot.
-                    PyObject *decoration = PyList_GET_ITEM(sig_obj, i);
+                    PyObject *decoration = PyList_GetItem(sig_obj, i);
                     Chimera::Signature *slot_signature = Chimera::Signature::fromPyObject(decoration);
 
-                    PyQtSlot *slot = new PyQtSlot(value, (PyObject *)pytype,
-                            slot_signature);;
+                    // Check if a slot of the same signature has already been
+                    // defined.  This typically happens with sub-classed
+                    // mixins.
+                    bool overridden = false;
 
-                    qo->pslots.append(slot);
+                    for (int i = 0; i < qo->pslots.size(); ++i)
+                        if (qo->pslots.at(i)->slotSignature()->signature == slot_signature->signature)
+                        {
+                            overridden = true;
+                            break;
+                        }
+
+                    if (!overridden)
+                        qo->pslots.append(
+                                new PyQtSlot(value, true, slot_signature));
                 }
             }
 
@@ -491,12 +433,15 @@ static int trawl_type(PyTypeObject *pytype, qpycore_metaobject *qo,
             const char *ascii_key = sipString_AsASCIIString(&key);
 
             // See if the value is of interest.
-            if (PyObject_TypeCheck(value, &qpycore_pyqtProperty_Type))
+            if (PyObject_TypeCheck(value, qpycore_pyqtProperty_TypeObject))
             {
                 // It is a property.
 
                 if (!ascii_key)
-                    return -1;
+                {
+                    rc = -1;
+                    break;
+                }
 
                 Py_INCREF(value);
 
@@ -512,17 +457,20 @@ static int trawl_type(PyTypeObject *pytype, qpycore_metaobject *qo,
                 if (mo)
                     builder.addRelatedMetaObject(mo);
             }
-            else if (PyObject_TypeCheck(value, &qpycore_pyqtSignal_Type))
+            else if (PyObject_TypeCheck(value, qpycore_pyqtSignal_TypeObject))
             {
                 // It is a signal.
 
                 if (!ascii_key)
-                    return -1;
+                {
+                    rc = -1;
+                    break;
+                }
 
                 qpycore_pyqtSignal *ps = (qpycore_pyqtSignal *)value;
 
                 // Make sure the signal has a name.
-                qpycore_set_signal_name(ps, pytype->tp_name, ascii_key);
+                qpycore_set_signal_name(ps, sipPyTypeName(pytype), ascii_key);
 
                 // Add all the overloads.
                 do
@@ -534,103 +482,72 @@ static int trawl_type(PyTypeObject *pytype, qpycore_metaobject *qo,
 
                 Py_DECREF(key);
             }
+            else
+            {
+                PyErr_Clear();
+            }
         }
     }
 
-    return 0;
+    Py_DECREF(dict);
+
+    return rc;
 }
 
 
 // Return the QMetaObject for an enum type's scope.
 static const QMetaObject *get_scope_qmetaobject(const Chimera *ct)
 {
-    // Check it is an enum.
-    if (!ct->isEnum())
+    // Check it is an enum.  Note that (starting with PyQt v6.8) we can return
+    // a value for all enums/flags.
+    if (!ct->isEnumOrFlag())
         return 0;
 
     // Check it has a scope.
+    if (!ct->typeDef())
+        return 0;
+
     const sipTypeDef *td = sipTypeScope(ct->typeDef());
 
     if (!td)
         return 0;
 
     // Check the scope is wrapped by PyQt.
-    if (!qpycore_is_pyqt_class(td))
+    if (!qpycore_is_pyqt_type(td))
         return 0;
 
-    return get_qmetaobject((pyqtWrapperType *)sipTypeAsPyTypeObject(td));
+    return qpycore_get_qmetaobject((sipWrapperType *)sipTypeAsPyTypeObject(td));
 }
 
 
 // Return the QMetaObject for a type.
-static const QMetaObject *get_qmetaobject(pyqtWrapperType *pyqt_wt)
+const QMetaObject *qpycore_get_qmetaobject(sipWrapperType *wt,
+        const sipTypeDef *base_td)
 {
-    // See if it's a sub-type of a wrapped type.
-    if (pyqt_wt->metaobject)
-        return pyqt_wt->metaobject->mo;
-
-    // It's a wrapped type.
-    return reinterpret_cast<const QMetaObject *>(((pyqt5ClassTypeDef *)((sipWrapperType *)pyqt_wt)->type)->static_metaobject);
-}
-
-
-#if defined(PYQT_QOBJECT_GUARD)
-
-// Reimplemented to wrap any QObjects created internally by Qt so that we can
-// detect if they get destroyed.
-static PyObject *pyqtWrapperType_call(PyObject *type, PyObject *args, PyObject *kwds)
-{
-    PyObject *self = sipWrapperType_Type->tp_call(type, args, kwds);
-
-    // See if the object was created and it is a QObject sub-class.
-    if (self && PyObject_TypeCheck(self, sipTypeAsPyTypeObject(sipType_QObject)))
+    if (wt && sipIsUserType(wt))
     {
-        sipSimpleWrapper *w = (sipSimpleWrapper *)self;
+        const qpycore_metaobject *qo = qpycore_get_dynamic_metaobject(wt);
 
-        // See if it is created internally by Qt and doesn't already have an
-        // access function (e.g. qApp).
-        if (!sipIsDerived(w) && !w->access_func)
-        {
-            QObject *qobj = reinterpret_cast<QObject *>(w->data);
-
-            // We can only guard objects in the same thread.
-            if (qobj->thread() == QThread::currentThread())
-            {
-                QWeakPointer<QObject> *guard = new QWeakPointer<QObject>(qobj);
-
-                w->data = guard;
-                w->access_func = qpointer_access_func;
-            }
-        }
+        if (qo)
+            return qo->mo;
     }
 
-    return self;
-}
-
-
-// The access function for guarded QObject pointers.
-static void *qpointer_access_func(sipSimpleWrapper *w, AccessFuncOp op)
-{
-    QWeakPointer<QObject> *guard = reinterpret_cast<QWeakPointer<QObject> *>(w->data);
-    void *addr;
-
-    switch (op)
+    // Get the static meta-object if there is one.
+    if (!base_td)
     {
-    case UnguardedPointer:
-        addr = guard->data();
-        break;
+        if (!wt)
+            return 0;
 
-    case GuardedPointer:
-        addr = guard->isNull() ? 0 : guard->data();
-        break;
+        base_td = sipTypeFromPyTypeObject((PyTypeObject *)wt);
 
-    case ReleaseGuard:
-        delete guard;
-        addr = 0;
-        break;
+        if (!base_td)
+            return 0;
     }
 
-    return addr;
-}
+    const pyqt6ClassPluginDef *plugin = reinterpret_cast<const pyqt6ClassPluginDef *>(sipTypePluginData(base_td));
 
-#endif
+    if (!plugin)
+        return 0;
+
+    return reinterpret_cast<const QMetaObject *>(plugin->static_metaobject);
+}
