@@ -1,8 +1,8 @@
 // This is the implementation of the various Chimera helpers.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -30,7 +30,7 @@
 
 
 // Forward declarations.
-static int QList_QObject_metatype();
+static QMetaType QList_QObject_metatype();
 static bool to_QList_QObject(PyObject *obj, QList<QObject *>&cpp);
 
 
@@ -38,7 +38,7 @@ static bool to_QList_QObject(PyObject *obj, QList<QObject *>&cpp);
 bool qpyquick_from_qvariant_convertor(const QVariant *varp, PyObject **objp)
 {
     // Check we handle the meta-type.
-    if (varp->userType() != QList_QObject_metatype())
+    if (varp->metaType() != QList_QObject_metatype())
         return false;
 
     const QList<QObject *> *cpp = reinterpret_cast<const QList<QObject *> *>(varp->data());
@@ -58,7 +58,7 @@ bool qpyquick_from_qvariant_convertor(const QVariant *varp, PyObject **objp)
                 break;
             }
 
-            PyList_SET_ITEM(obj, i, itm);
+            PyList_SetItem(obj, i, itm);
         }
     }
 
@@ -71,10 +71,10 @@ bool qpyquick_from_qvariant_convertor(const QVariant *varp, PyObject **objp)
 // Convert a Python object to a QVariant.
 bool qpyquick_to_qvariant_convertor(PyObject *obj, QVariant &var, bool *okp)
 {
-    int metatype = QList_QObject_metatype();
+    QMetaType metatype = QList_QObject_metatype();
 
     // Check the meta-type has been defined.
-    if (metatype == 0)
+    if (!metatype.isValid())
         return false;
 
     QList<QObject *> qlo;
@@ -93,7 +93,7 @@ bool qpyquick_to_qvariant_convertor(PyObject *obj, QVariant &var, bool *okp)
 
 // Convert a Python object to QVariant data.
 bool qpyquick_to_qvariant_data_convertor(PyObject *obj, void *data,
-        int metatype, bool *okp)
+        QMetaType metatype, bool *okp)
 {
     // Check we handle the meta-type.
     if (metatype != QList_QObject_metatype())
@@ -114,14 +114,14 @@ bool qpyquick_to_qvariant_data_convertor(PyObject *obj, void *data,
 
 
 // Get the metatype for QList<QObject *> or 0 if it hasn't been registered.
-static int QList_QObject_metatype()
+static QMetaType QList_QObject_metatype()
 {
-    static int lo_metatype = 0;
+    static QMetaType lo_metatype;
 
     // We look each time until we find it rather than rely on any particular
     // behaviour from QtQuick.
-    if (lo_metatype == 0)
-        lo_metatype = QMetaType::type("QList<QObject*>");
+    if (!lo_metatype.isValid())
+        lo_metatype = QMetaType::fromType<QList<QObject *> >();
 
     return lo_metatype;
 }
@@ -132,12 +132,12 @@ static int QList_QObject_metatype()
 // QtCore module to handle.
 static bool to_QList_QObject(PyObject *obj, QList<QObject *>&cpp)
 {
-    if (!PyList_CheckExact(obj) || PyList_GET_SIZE(obj) == 0)
+    if (!PyList_CheckExact(obj) || PyList_Size(obj) == 0)
         return false;
 
-    for (SIP_SSIZE_T i = 0; i < PyList_GET_SIZE(obj); ++i)
+    for (Py_ssize_t i = 0; i < PyList_Size(obj); ++i)
     {
-        PyObject *val_obj = PyList_GET_ITEM(obj, i);
+        PyObject *val_obj = PyList_GetItem(obj, i);
 
         if (!val_obj)
             return false;
