@@ -1,8 +1,8 @@
 // This is the initialisation support code for the QtQuick module.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -25,22 +25,34 @@
 #include "sipAPIQtQuick.h"
 
 
+// Imports from QtCore.
+pyqt6_qtquick_err_print_t pyqt6_qtquick_err_print;
+
+
 // Perform any required initialisation.
 void qpyquick_post_init()
 {
     // Import the Chimera helper registration functions.
     void (*register_from_qvariant_convertor)(FromQVariantConvertorFn);
-    register_from_qvariant_convertor = (void (*)(FromQVariantConvertorFn))sipImportSymbol("pyqt5_register_from_qvariant_convertor");
+    register_from_qvariant_convertor = (void (*)(FromQVariantConvertorFn))sipImportSymbol("pyqt6_register_from_qvariant_convertor");
+    Q_ASSERT(register_from_qvariant_convertor);
     register_from_qvariant_convertor(qpyquick_from_qvariant_convertor);
 
     void (*register_to_qvariant_convertor)(ToQVariantConvertorFn);
-    register_to_qvariant_convertor = (void (*)(ToQVariantConvertorFn))sipImportSymbol("pyqt5_register_to_qvariant_convertor");
+    register_to_qvariant_convertor = (void (*)(ToQVariantConvertorFn))sipImportSymbol("pyqt6_register_to_qvariant_convertor");
+    Q_ASSERT(register_to_qvariant_convertor);
     register_to_qvariant_convertor(qpyquick_to_qvariant_convertor);
 
     void (*register_to_qvariant_data_convertor)(ToQVariantDataConvertorFn);
-    register_to_qvariant_data_convertor = (void (*)(ToQVariantDataConvertorFn))sipImportSymbol("pyqt5_register_to_qvariant_data_convertor");
+    register_to_qvariant_data_convertor = (void (*)(ToQVariantDataConvertorFn))sipImportSymbol("pyqt6_register_to_qvariant_data_convertor");
+    Q_ASSERT(register_to_qvariant_data_convertor);
     register_to_qvariant_data_convertor(qpyquick_to_qvariant_data_convertor);
 
+    // Other QtCore imports.
+    pyqt6_qtquick_err_print = (pyqt6_qtquick_err_print_t)sipImportSymbol(
+            "pyqt6_err_print");
+    Q_ASSERT(pyqt6_qtquick_err_print);
+
     // Export the qml_register_type() helper.
     sipExportSymbol("qtquick_register_item", (void *)qpyquick_register_type);
 }
