@@ -1,8 +1,8 @@
 // This is the definition of the QPyQuickItem classes.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -56,6 +56,7 @@ class QPyQuickItem##n : public QPyQuickItem \
 public: \
     QPyQuickItem##n(QQuickItem *parent = 0); \
     static QMetaObject staticMetaObject; \
+    virtual const QMetaObject *metaObject() const; \
     virtual int typeNr() const {return n##U;} \
 private: \
     QPyQuickItem##n(const QPyQuickItem##n &); \
@@ -92,6 +93,36 @@ QPYQUICKITEM_DECL(26);
 QPYQUICKITEM_DECL(27);
 QPYQUICKITEM_DECL(28);
 QPYQUICKITEM_DECL(29);
+QPYQUICKITEM_DECL(30);
+QPYQUICKITEM_DECL(31);
+QPYQUICKITEM_DECL(32);
+QPYQUICKITEM_DECL(33);
+QPYQUICKITEM_DECL(34);
+QPYQUICKITEM_DECL(35);
+QPYQUICKITEM_DECL(36);
+QPYQUICKITEM_DECL(37);
+QPYQUICKITEM_DECL(38);
+QPYQUICKITEM_DECL(39);
+QPYQUICKITEM_DECL(40);
+QPYQUICKITEM_DECL(41);
+QPYQUICKITEM_DECL(42);
+QPYQUICKITEM_DECL(43);
+QPYQUICKITEM_DECL(44);
+QPYQUICKITEM_DECL(45);
+QPYQUICKITEM_DECL(46);
+QPYQUICKITEM_DECL(47);
+QPYQUICKITEM_DECL(48);
+QPYQUICKITEM_DECL(49);
+QPYQUICKITEM_DECL(50);
+QPYQUICKITEM_DECL(51);
+QPYQUICKITEM_DECL(52);
+QPYQUICKITEM_DECL(53);
+QPYQUICKITEM_DECL(54);
+QPYQUICKITEM_DECL(55);
+QPYQUICKITEM_DECL(56);
+QPYQUICKITEM_DECL(57);
+QPYQUICKITEM_DECL(58);
+QPYQUICKITEM_DECL(59);
 
 
 #endif
